==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/config/CfnAggregationAuthorizationProps.java <==
package software.amazon.awscdk.services.config;

/**
 * Properties for defining a `AWS::Config::AggregationAuthorization`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:16.779Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.CfnAggregationAuthorizationProps")
@software.amazon.jsii.Jsii.Proxy(CfnAggregationAuthorizationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnAggregationAuthorizationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Config::AggregationAuthorization.AuthorizedAccountId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAuthorizedAccountId();

    /**
     * `AWS::Config::AggregationAuthorization.AuthorizedAwsRegion`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAuthorizedAwsRegion();

    /**
     * `AWS::Config::AggregationAuthorization.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnAggregationAuthorizationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnAggregationAuthorizationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnAggregationAuthorizationProps> {
        private java.lang.String authorizedAccountId;
        private java.lang.String authorizedAwsRegion;
        private java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Sets the value of {@link CfnAggregationAuthorizationProps#getAuthorizedAccountId}
         * @param authorizedAccountId `AWS::Config::AggregationAuthorization.AuthorizedAccountId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder authorizedAccountId(java.lang.String authorizedAccountId) {
            this.authorizedAccountId = authorizedAccountId;
            return this;
        }

        /**
         * Sets the value of {@link CfnAggregationAuthorizationProps#getAuthorizedAwsRegion}
         * @param authorizedAwsRegion `AWS::Config::AggregationAuthorization.AuthorizedAwsRegion`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder authorizedAwsRegion(java.lang.String authorizedAwsRegion) {
            this.authorizedAwsRegion = authorizedAwsRegion;
            return this;
        }

        /**
         * Sets the value of {@link CfnAggregationAuthorizationProps#getTags}
         * @param tags `AWS::Config::AggregationAuthorization.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnAggregationAuthorizationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnAggregationAuthorizationProps build() {
            return new Jsii$Proxy(authorizedAccountId, authorizedAwsRegion, tags);
        }
    }

    /**
     * An implementation for {@link CfnAggregationAuthorizationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnAggregationAuthorizationProps {
        private final java.lang.String authorizedAccountId;
        private final java.lang.String authorizedAwsRegion;
        private final java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.authorizedAccountId = software.amazon.jsii.Kernel.get(this, "authorizedAccountId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.authorizedAwsRegion = software.amazon.jsii.Kernel.get(this, "authorizedAwsRegion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String authorizedAccountId, final java.lang.String authorizedAwsRegion, final java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.authorizedAccountId = java.util.Objects.requireNonNull(authorizedAccountId, "authorizedAccountId is required");
            this.authorizedAwsRegion = java.util.Objects.requireNonNull(authorizedAwsRegion, "authorizedAwsRegion is required");
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
        }

        @Override
        public final java.lang.String getAuthorizedAccountId() {
            return this.authorizedAccountId;
        }

        @Override
        public final java.lang.String getAuthorizedAwsRegion() {
            return this.authorizedAwsRegion;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("authorizedAccountId", om.valueToTree(this.getAuthorizedAccountId()));
            data.set("authorizedAwsRegion", om.valueToTree(this.getAuthorizedAwsRegion()));
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.CfnAggregationAuthorizationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnAggregationAuthorizationProps.Jsii$Proxy that = (CfnAggregationAuthorizationProps.Jsii$Proxy) o;

            if (!authorizedAccountId.equals(that.authorizedAccountId)) return false;
            if (!authorizedAwsRegion.equals(that.authorizedAwsRegion)) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.authorizedAccountId.hashCode();
            result = 31 * result + (this.authorizedAwsRegion.hashCode());
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/config/CfnAggregationAuthorizationProps.java <==
package software.amazon.awscdk.services.config;

/**
 * Properties for defining a `CfnAggregationAuthorization`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.config.*;
 * CfnAggregationAuthorizationProps cfnAggregationAuthorizationProps = CfnAggregationAuthorizationProps.builder()
 *         .authorizedAccountId("authorizedAccountId")
 *         .authorizedAwsRegion("authorizedAwsRegion")
 *         // the properties below are optional
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.602Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.CfnAggregationAuthorizationProps")
@software.amazon.jsii.Jsii.Proxy(CfnAggregationAuthorizationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnAggregationAuthorizationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The 12-digit account ID of the account authorized to aggregate data.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAuthorizedAccountId();

    /**
     * The region authorized to collect aggregated data.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAuthorizedAwsRegion();

    /**
     * An array of tag object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnAggregationAuthorizationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnAggregationAuthorizationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnAggregationAuthorizationProps> {
        java.lang.String authorizedAccountId;
        java.lang.String authorizedAwsRegion;
        java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Sets the value of {@link CfnAggregationAuthorizationProps#getAuthorizedAccountId}
         * @param authorizedAccountId The 12-digit account ID of the account authorized to aggregate data. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder authorizedAccountId(java.lang.String authorizedAccountId) {
            this.authorizedAccountId = authorizedAccountId;
            return this;
        }

        /**
         * Sets the value of {@link CfnAggregationAuthorizationProps#getAuthorizedAwsRegion}
         * @param authorizedAwsRegion The region authorized to collect aggregated data. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder authorizedAwsRegion(java.lang.String authorizedAwsRegion) {
            this.authorizedAwsRegion = authorizedAwsRegion;
            return this;
        }

        /**
         * Sets the value of {@link CfnAggregationAuthorizationProps#getTags}
         * @param tags An array of tag object.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnAggregationAuthorizationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnAggregationAuthorizationProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnAggregationAuthorizationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnAggregationAuthorizationProps {
        private final java.lang.String authorizedAccountId;
        private final java.lang.String authorizedAwsRegion;
        private final java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.authorizedAccountId = software.amazon.jsii.Kernel.get(this, "authorizedAccountId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.authorizedAwsRegion = software.amazon.jsii.Kernel.get(this, "authorizedAwsRegion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.authorizedAccountId = java.util.Objects.requireNonNull(builder.authorizedAccountId, "authorizedAccountId is required");
            this.authorizedAwsRegion = java.util.Objects.requireNonNull(builder.authorizedAwsRegion, "authorizedAwsRegion is required");
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.String getAuthorizedAccountId() {
            return this.authorizedAccountId;
        }

        @Override
        public final java.lang.String getAuthorizedAwsRegion() {
            return this.authorizedAwsRegion;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("authorizedAccountId", om.valueToTree(this.getAuthorizedAccountId()));
            data.set("authorizedAwsRegion", om.valueToTree(this.getAuthorizedAwsRegion()));
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.CfnAggregationAuthorizationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnAggregationAuthorizationProps.Jsii$Proxy that = (CfnAggregationAuthorizationProps.Jsii$Proxy) o;

            if (!authorizedAccountId.equals(that.authorizedAccountId)) return false;
            if (!authorizedAwsRegion.equals(that.authorizedAwsRegion)) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.authorizedAccountId.hashCode();
            result = 31 * result + (this.authorizedAwsRegion.hashCode());
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
